import"./outputWidgets.d6334d0e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7ac8b799-02d6-4717-8e9a-d9b4fce26f19",e._sentryDebugIdIdentifier="sentry-dbid-7ac8b799-02d6-4717-8e9a-d9b4fce26f19")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.dce42ecb.js.map
