import{d as r,r as u,o as c,eS as f,b as y,c as b,w as d,f as p,aB as g,eB as m,eO as w,u as i,b_ as _,eW as k}from"./outputWidgets.d6334d0e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="bce84dab-b57e-4373-9f15-3801291d18de",e._sentryDebugIdIdentifier="sentry-dbid-bce84dab-b57e-4373-9f15-3801291d18de")}catch{}})();const v=r({__name:"ActionButton",props:{action:{},displayName:{},loading:{type:Boolean}},emits:["click"],setup(e,{emit:n}){const o=e,a=u(null);return c(()=>{a.value&&o.action.setElement(a.value),f.addAction(o.action)}),(s,t)=>(y(),b(i(k),null,{default:d(()=>[p(i(_),{ref_key:"element",ref:a,class:"next-button",loading:s.loading,onClick:t[0]||(t[0]=l=>n("click")),onKeydown:t[1]||(t[1]=w(l=>n("click"),["enter"]))},{default:d(()=>[g(m(s.displayName),1)]),_:1},8,["loading"])]),_:1}))}});export{v as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.6b0fc39f.js.map
