import{R as n}from"./Title.132c3f7f.js";import{E as f}from"./outputWidgets.d6334d0e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0f95177c-c954-4c71-ae98-3fa19f9eb86e",e._sentryDebugIdIdentifier="sentry-dbid-0f95177c-c954-4c71-ae98-3fa19f9eb86e")}catch{}})();const d=f(n);export{d as A};
//# sourceMappingURL=index.e0fb68fa.js.map
