import{d as b,ey as g,ez as v,r as _,b as r,c as s,w as a,u as e,f as n,ev as m}from"./outputWidgets.d6334d0e.js";import{S as h,L as w}from"./SmartConsole.23edeb7d.js";import{a as x}from"./asyncComputed.95fd0999.js";import{H as B}from"./hooks.41346d54.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.6237af7f.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.cfa74815.js";import{B as I}from"./BaseLayout.17a4d39d.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.9c4485f7.js";import{_ as $}from"./Debugger.vue_vue_type_script_setup_true_lang.5b576fab.js";import{c as D}from"./index.02b3bfd1.js";import{A as k,T as R}from"./TabPane.c6ad6225.js";import"./forms.7ea2277d.js";import"./activeRecord.aa738a85.js";import"./pubsub.9d7d329e.js";import"./dashes.0b98440a.js";import"./runnerData.f9a0f655.js";import"./jobs.bc007f42.js";import"./workspaces.27037c79.js";import"./url.dce42ecb.js";import"./icons.09e1f108.js";import"./Title.132c3f7f.js";import"./transButton.97ae4a5a.js";import"./index.e0fb68fa.js";import"./uuid.09e03d40.js";import"./ant-design.765336cf.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.4f16d044.js";import"./RunButton.vue_vue_type_script_setup_true_lang.b2f43942.js";import"./index.b09d6541.js";import"./index.98d66b02.js";import"./CollapsePanel.2424664e.js";import"./index.6da051f8.js";import"./index.2221e01c.js";import"./index.9476b093.js";import"./Form.afe8a620.js";import"./Text.2f6a30da.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},p=new Error().stack;p&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[p]="1fa6fe61-cb95-428f-b8b5-1e08f8b8813a",i._sentryDebugIdIdentifier="sentry-dbid-1fa6fe61-cb95-428f-b8b5-1e08f8b8813a")}catch{}})();const _e=b({__name:"HookEditor",setup(i){const p=g(),u=v(),l=_(null),o=_("test");function y(){p.push({name:"hooks"})}const{result:t}=x(()=>B.get(u.params.hookPath)),c=w.create();return(A,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[n(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=f=>o.value=f)},{default:a(()=>[n(e(k),{key:"test",tab:"Test"}),n(e(k),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[n($),n(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):m("",!0)]),_:1},8,["title"])):m("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:l,hook:e(t),"log-service":e(c)},null,8,["hook","log-service"])):m("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):m("",!0)]),footer:a(()=>{var f;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(c),onRestart:(f=l.value)==null?void 0:f.runHook},null,8,["log-service","onRestart"])):m("",!0)]}),_:1}))}});export{_e as default};
//# sourceMappingURL=HookEditor.b0dce16e.js.map
