import{v as t,b as s,et as a}from"./outputWidgets.d6334d0e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e5cad2cd-ffbb-4c8b-824b-a40016c42dae",e._sentryDebugIdIdentifier="sentry-dbid-e5cad2cd-ffbb-4c8b-824b-a40016c42dae")}catch{}})();const c={},d={class:"organization-settings"};function o(e,n){return s(),a("div",d,"Organization settings")}const f=t(c,[["render",o]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.c81c0873.js.map
