import{x as s}from"./icons.09e1f108.js";import{d as r,a as c,b as i,et as d,f as _,u as f,aB as l,v as u}from"./outputWidgets.d6334d0e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="139034a2-75b8-49db-96fb-a8859b8e70f1",e._sentryDebugIdIdentifier="sentry-dbid-139034a2-75b8-49db-96fb-a8859b8e70f1")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:f(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const B=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{B};
//# sourceMappingURL=BackButton.575a40cc.js.map
