import{v as o,a as r,b as i,c,i as d,T as p,j as u,P as _,C as f,M as l,s as b,k as s,l as g,m,n as y,p as v}from"./outputWidgets.d6334d0e.js";import{u as w,a}from"./index.39da7992.js";import"./pubsub.9d7d329e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="28e35abc-3a69-4f14-ac31-a9ebaadd6e50",e._sentryDebugIdIdentifier="sentry-dbid-28e35abc-3a69-4f14-ac31-a9ebaadd6e50")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=o(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>g(k)});p.init(),u(e,a),x.init(),e.use(a),e.use(_),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",b),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.16da3519.js.map
