import"./outputWidgets.d6334d0e.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="27ea86bd-372f-4371-96f3-9b6970663d8e",x._sentryDebugIdIdentifier="sentry-dbid-27ea86bd-372f-4371-96f3-9b6970663d8e")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)}),d=()=>Math.random().toString(36).slice(2);export{d as r,r as u};
//# sourceMappingURL=uuid.09e03d40.js.map
