import{V as t,f as d,Q as c,ac as y}from"./outputWidgets.d6334d0e.js";import{B as i,c as f}from"./Title.132c3f7f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="39e3b41f-ec9c-4adc-95fa-a9c97fc9fd6b",e._sentryDebugIdIdentifier="sentry-dbid-39e3b41f-ec9c-4adc-95fa-a9c97fc9fd6b")}catch{}})();const g=()=>c(f(),["component"]),r=(e,a)=>{let{slots:o,attrs:p}=a;const s=t(t(t({},e),{component:"div"}),p);return d(i,s,o)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=g();const m=r,b=()=>t(t({},c(f(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),n=(e,a)=>{let{slots:o,attrs:p}=a;const{ellipsis:s}=e;y();const l=t(t(t({},e),{ellipsis:s&&typeof s=="object"?c(s,["expandable","rows"]):s,component:"span"}),p);return d(i,l,o)};n.displayName="ATypographyText";n.inheritAttrs=!1;n.props=b();const x=n;export{m as A,x as a};
//# sourceMappingURL=Text.2f6a30da.js.map
