import{d as b,es as v,G as y,b as d,et as c,e as l,u as g,eu as r,at as p,ev as w,ew as h,ex as S,v as m,r as k,a as C,f,w as I,b9 as x}from"./outputWidgets.d6334d0e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="adaea8fb-ba57-40a4-9be8-c5dc6eb15bab",e._sentryDebugIdIdentifier="sentry-dbid-adaea8fb-ba57-40a4-9be8-c5dc6eb15bab")}catch{}})();const D=b({__name:"Modal",props:{containerStyle:{},headerStyle:{},contentStyle:{}},emits:["open","close"],setup(e,{expose:s,emit:t}){const i=v(),_=()=>{a.isOpened=!0,t("open")},n=()=>{a.isOpened=!1,t("close")};s({open:_,close:n});const a=y({isOpened:!1});return(o,u)=>(d(),c("div",{class:S(["background",a.isOpened&&"visible"]),onClick:n},[l("div",{class:"container",style:r(o.containerStyle),onClick:u[0]||(u[0]=h(()=>{},["stop"]))},[g(i).header?(d(),c("div",{key:0,class:"header",style:r(o.headerStyle)},[p(o.$slots,"header",{},void 0,!0)],4)):w("",!0),l("div",{class:"content",style:r(o.contentStyle)},[p(o.$slots,"content",{},void 0,!0)],4)],4)],2))}});const M=m(D,[["__scopeId","data-v-24f739ca"]]),O=["src"],B=b({__name:"Home",setup(e){const s=y({onboardingForm:""}),t=k(null);return(i,_)=>{const n=C("router-view");return d(),c(x,null,[f(n,{class:"router"}),f(M,{ref_key:"modal",ref:t},{content:I(()=>[l("iframe",{class:"form",src:s.onboardingForm},null,8,O)]),_:1},512)],64)}}});const H=m(B,[["__scopeId","data-v-7e290e34"]]);export{H as default};
//# sourceMappingURL=Home.b395725f.js.map
