import{cA as n}from"./outputWidgets.d6334d0e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="5f0ca5de-9e9a-4b02-873e-1b40f98ae97b",e._sentryDebugIdIdentifier="sentry-dbid-5f0ca5de-9e9a-4b02-873e-1b40f98ae97b")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.03d4e2fa.js.map
