import{d as g,ey as v,ez as k,r as _,b as r,c as s,w as a,u as e,f as n,ev as m}from"./outputWidgets.d6334d0e.js";import{S as j,L as w}from"./SmartConsole.23edeb7d.js";import{a as x}from"./asyncComputed.95fd0999.js";import{J as I}from"./jobs.bc007f42.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.6237af7f.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.cfa74815.js";import{B as S}from"./BaseLayout.17a4d39d.js";import{_ as T,a as $}from"./JobSettings.vue_vue_type_script_setup_true_lang.4494a77b.js";import{_ as D}from"./Debugger.vue_vue_type_script_setup_true_lang.5b576fab.js";import{c as R}from"./index.02b3bfd1.js";import{A as b,T as A}from"./TabPane.c6ad6225.js";import"./forms.7ea2277d.js";import"./activeRecord.aa738a85.js";import"./pubsub.9d7d329e.js";import"./dashes.0b98440a.js";import"./runnerData.f9a0f655.js";import"./hooks.41346d54.js";import"./workspaces.27037c79.js";import"./url.dce42ecb.js";import"./icons.09e1f108.js";import"./Title.132c3f7f.js";import"./transButton.97ae4a5a.js";import"./index.e0fb68fa.js";import"./uuid.09e03d40.js";import"./ant-design.765336cf.js";import"./RunButton.vue_vue_type_script_setup_true_lang.b2f43942.js";import"./index.c9593da1.js";import"./index.9476b093.js";import"./dayjs.a79e5d2c.js";import"./Form.afe8a620.js";import"./Text.2f6a30da.js";import"./index.6da051f8.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[c]="bc7c747e-d5c5-4cd3-94f0-951846ad7c38",i._sentryDebugIdIdentifier="sentry-dbid-bc7c747e-d5c5-4cd3-94f0-951846ad7c38")}catch{}})();const le=g({__name:"JobEditor",setup(i){const c=v(),u=k(),l=_(null),o=_("test");function y(){c.push({name:"jobs"})}const{result:t}=x(()=>I.get(u.params.jobId)),f=w.create();return(J,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(R),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[n(e(A),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[n(e(b),{key:"test",tab:"Test"}),n(e(b),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[n(D),n(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):m("",!0)]),_:1},8,["title"])):m("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:l,job:e(t),"log-service":e(f)},null,8,["job","log-service"])):m("",!0),e(t)&&o.value==="settings"?(r(),s($,{key:1,job:e(t)},null,8,["job"])):m("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(j,{key:0,runtime:"forms","log-service":e(f),onRestart:(p=l.value)==null?void 0:p.test},null,8,["log-service","onRestart"])):m("",!0)]}),_:1}))}});export{le as default};
//# sourceMappingURL=JobEditor.e46e66da.js.map
