import{S as p}from"./Sidebar.e2f3ae2b.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.321a03d1.js";import{G as l,H as d,I as u}from"./icons.09e1f108.js";import{d as b,ez as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.d6334d0e.js";import{a as w}from"./asyncComputed.95fd0999.js";import"./router.c9839d0e.js";import{O as z}from"./organization.bb04fda1.js";import"./columns.6b92da60.js";import{B as h}from"./BaseLayout.17a4d39d.js";import"./Tooltip.bb730cca.js";import"./logo.084e5d7c.js";import"./Text.2f6a30da.js";import"./Title.132c3f7f.js";import"./transButton.97ae4a5a.js";import"./index.6da051f8.js";import"./index.02b3bfd1.js";import"./Form.afe8a620.js";import"./index.85dd1fea.js";import"./gateway.78108c4a.js";import"./activeRecord.aa738a85.js";import"./pubsub.9d7d329e.js";import"./index.f4ac7424.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d492825f-2be3-449e-8807-459079981ae5",e._sentryDebugIdIdentifier="sentry-dbid-d492825f-2be3-449e-8807-459079981ae5")}catch{}})();const Q=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:t}=w(()=>z.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:d,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{Q as default};
//# sourceMappingURL=Organization.9c8e1e87.js.map
